@@ -13,21 +13,59 @@ module Debci
   #     >> Debci.config.data_basedir
   #     => "/path/to/debci/data"
   #
-  Config = Struct.new(:data_basedir, :html_dir, :sendmail_from, :sendmail_to, :url_base, :artifacts_url_base, :config_dir, :packages_dir, :distro_name, :data_retention_days) do
+  Config = Struct.new(
+    :amqp_server,
+    :arch,
+    :arch_list,
+    :artifacts_url_base,
+    :backend,
+    :config_dir,
+    :data_basedir,
+    :data_retention_days,
+    :database_url,
+    :distro_name,
+    :html_dir,
+    :packages_dir,
+    :quiet,
+    :secrets_dir,
+    :sendmail_from,
+    :sendmail_to,
+    :suite,
+    :suite_list,
+    :url_base,
+  ) do
 
     # for development usage
-    if !ENV['ADTTMP'] && !system('which debci >/dev/null')
+    if !ENV['ADTTMP']
       bin = File.dirname(__FILE__) + '/../../bin'
       if File.exists?(bin)
         ENV['PATH'] = [bin,ENV['PATH']].join(':')
       end
     end
 
+    def self.types
+      @types ||= {
+        /_list$/ => lambda { |x| x.split}, # Array
+        'quiet' => lambda { |x| x == 'true' }, # boolean
+      }
+    end
+
+    def self.cast_for(key)
+      pair = types.find { |k,v| k === key }
+      if pair
+        pair[1]
+      else
+        lambda { |x| x == "" ? nil : x }
+      end
+    end
+
     def initialize
       # :nodoc:
       IO.popen(['debci', 'config', *members.map(&:to_s)]) do |data|
         data.each_line.each do |line|
-          key, value = line.strip.split('=')
+          key, value = line.strip.split('=', 2)
+          cast = self.class.cast_for(key)
+          value = cast.call(value)
           self.send("#{key}=", value)
         end
       end
