@@ -1,6 +1,8 @@
+require 'cgi'
 require 'erb'
 
 require 'debci'
+require 'debci/job'
 require 'fileutils'
 
 module Debci
@@ -33,6 +35,17 @@ module Debci
       expand_template(:status_alerts, filename)
     end
 
+    def status_slow(filename)
+      @slow = @repository.slow_packages
+      expand_template(:status_slow, filename)
+    end
+
+    def status_pending_jobs(filename)
+      @status_nav = load_template(:status_nav)
+      @pending = Debci::Job.pending
+      expand_template(:status_pending_jobs, filename)
+    end
+
     def platform_specific_issues(filename)
       @status_nav = load_template(:status_nav)
       @issues = @repository.platform_specific_issues
@@ -82,15 +95,21 @@ module Debci
 
     private
 
+    def templates
+      @templates ||= {}
+    end
+
     def load_template(template)
       read_template(template).result(binding)
     end
 
     def read_template(name)
-      filename = File.join(File.dirname(__FILE__), 'html', name.to_s + '.erb')
-      template = ERB.new(File.read(filename))
-      template.filename = filename
-      template
+      templates[name] ||= begin
+        filename = File.join(File.dirname(__FILE__), 'html', name.to_s + '.erb')
+        template = ERB.new(File.read(filename))
+        template.filename = filename
+        template
+      end
     end
 
     def expand_template(template, filename)
@@ -117,6 +136,28 @@ module Debci
       end
     end
 
+    def escape(text)
+      text && CGI.escapeHTML(text)
+    end
+
+    ICONS = {
+      pass: 'thumbs-up',
+      neutral: 'minus-circle',
+      fail: 'thumbs-down',
+      fail_passed_never: ['thumbs-down', 'ban'],
+      fail_passed_current: ['thumbs-down', 'bolt'],
+      fail_passed_old: ['thumbs-down', 'arrow-down'],
+      tmpfail_pass: 'thumbs-up',
+      tmpfail_fail: 'thumbs-down',
+      tmpfail: 'question-circle',
+      no_test_data: 'question',
+    }
+    def icon(status)
+      Array(ICONS[status.to_sym]).map do |i|
+        "<i class='#{status} fa fa-#{i}'></i>"
+      end.join(' ')
+    end
+
   end
 
 end
