@@ -43,8 +43,7 @@ debci_suite=${debci_suite:-unstable}
 debci_suite_list=${debci_suite_list:-${debci_suite}}
 debci_arch=${debci_arch:-$(dpkg --print-architecture)}
 debci_arch_list="${debci_arch_list:-${debci_arch}}"
-# debci-setup-chdist determines the default from debootstrap, don't set one here
-debci_mirror=
+debci_mirror=${debci_mirror:-${MIRROR:-http://deb.debian.org/debian}}
 debci_backend=${debci_backend:-lxc}
 debci_data_basedir=${debci_data_basedir:-$(readlink -f "${debci_base_dir}/data")}
 debci_quiet="${debci_quiet:-false}"
@@ -59,8 +58,8 @@ debci_database_url="${debci_database_url:-sqlite3://$debci_data_basedir/debci.sq
 
 debci_secrets_dir=${debci_secrets_dir:-$(readlink -f "${debci_base_dir}/secrets")}
 
-shared_short_options='c:s:a:b:d:hq'
-shared_long_options='config:,suite:,arch:,backend:,data-dir:,amqp:,help,quiet'
+shared_short_options='c:s:a:b:d:m:hq'
+shared_long_options='config:,suite:,arch:,backend:,data-dir:,amqp:,mirror:,help,quiet'
 
 usage_shared_options="Common options:
 
@@ -76,6 +75,8 @@ usage_shared_options="Common options:
                             and where it will read from
   --amqp amqp://[user:password@]hostname[:port]
                             AMQP server to connect to (default: ${debci_amqp_server})
+  -m URL, --mirror URL      selects which mirror to use for APT-related actions,
+                            i.e. creating test backends, pulling sources files, etc.
   -q, --quiet               prevents debci from producing any output on stdout
   --help                    show this usage message
 "
@@ -114,6 +115,9 @@ for arg in "$@"; do
       --amqp)
         var=debci_amqp_server
         ;;
+      -m|--mirror)
+        var=debci_mirror
+        ;;
       -q|--quiet)
         export debci_quiet=true
         ;;
@@ -128,6 +132,9 @@ for arg in "$@"; do
   fi
 done
 
+# This is used in lxc by the lxc-debian template, and by autopkgtest-build-*
+export MIRROR="${debci_mirror}"
+
 alias prepare_args='while [ "$1" != "--" ]; do shift; done; shift'
 
 debci_autopkgtest_dir="${debci_data_basedir}/autopkgtest/${debci_suite}/${debci_arch}"
