@@ -12,8 +12,18 @@ describe Debci::Config do
   end
 
   KEYS.each do |key|
-    it "knows about #{key}" do
-      expect(config.send(key)).to be_a(String)
+    if key =~ /_list$/
+      it "knows about #{key}" do
+        expect(config.send(key)).to be_a(Array)
+      end
+    elsif key == :quiet
+      it "knows about #{key}" do
+        expect(config.send(key)).to_not be_a(String)
+      end
+    else
+      it "knows about #{key}" do
+        expect(config.send(key)).to be_a(String)
+      end
     end
     it "strips newlines off #{key}" do
       expect(config.send(key)).to_not end_with("\n")
@@ -26,4 +36,10 @@ describe Debci::Config do
     expect(config.data_basedir).to eq('/path/to/data')
   end
 
+  it 'splits at the first equal sign only' do
+    url = "sqlite3:/path/to/db.sqlite3?timeout=5000"
+    @io.reopen("database_url=#{url}\n")
+    expect(config.database_url).to eq(url)
+  end
+
 end
