@@ -1,3 +1,4 @@
+require 'debci'
 require 'debci/repository'
 
 require 'tmpdir'
@@ -23,7 +24,9 @@ describe Debci::Repository do
 
     history 'packages/unstable/amd64/r/rake', [{'status' => 'fail', 'date' => '2014-08-01 11:11:12'},
                                                {'status' => 'pass', 'date' => '2014-07-07 12:12:15'},
-                                               {'status' => 'tmpfail', 'date' => '2014-03-01 14:15:30'}]
+                                               {'status' => 'tmpfail', 'date' => '2014-03-01 14:15:30'},
+                                               {'status' => 'fail', 'date' => '2015-03-01 14:15:30'},
+                                               {'status' => 'pass', 'date' => '2016-03-01 14:15:30'}]
 
     mkdir_p 'packages/unstable/amd64/r/rake-compiler'
     mkdir_p 'packages/unstable/i386/r/rake-compiler'
@@ -66,6 +69,12 @@ describe Debci::Repository do
       'status' => 'tmpfail',
       'previous_status' => 'pass',
     }
+
+    mkdir_p 'packages/unstable/amd64/s/slowpackage'
+    latest_status 'packages/unstable/amd64/s/slowpackage', {
+      'status' => 'pass',
+      'duration_seconds' => 5000,
+    }
   end
 
   attr_reader :now
@@ -79,8 +88,9 @@ describe Debci::Repository do
   end
 
   def past_status(path, data, run_id)
+    package = File.basename(path)
     File.open(File.join(@datadir, path, run_id + '.json'), 'w') do |f|
-      f.write(JSON.dump({ 'run_id' => run_id }.merge(data)))
+      f.write(JSON.dump({ 'package' => package, 'run_id' => run_id }.merge(data)))
     end
   end
 
@@ -208,6 +218,15 @@ describe Debci::Repository do
     end
   end
 
+  it 'sorts status history for a package by date in descending order' do
+    history = repository.history_for('rake', 'unstable', 'amd64')
+
+    expect(history.first.status).to eq(:pass)
+    expect(history.first.date.to_s).to eq('2016-03-01 14:15:30 UTC')
+    expect(history.last.status).to eq(:tmpfail)
+    expect(history.last.date.to_s).to eq('2014-03-01 14:15:30 UTC')
+  end
+
   it 'knows which packages are temporarily failing' do
     tmpfail_packages = repository.tmpfail_packages
 
@@ -223,6 +242,15 @@ describe Debci::Repository do
     end
   end
 
+  it 'knows about slow-running tests' do
+    slow = repository.slow_packages
+    expect(slow).to be_a(Array)
+    expect(slow.length).to be >= 1
+
+    status = slow.find { |status| status.package == 'slowpackage' }
+    expect(status).to be_a(Debci::Status)
+  end
+
   it 'knows about platform-specific issues' do
     issues = repository.platform_specific_issues
     expect(issues).to have_key('rubygems-integration')
