@@ -17,7 +17,6 @@ describe Debci::Status do
         "version" => "10.1.1-1",
         "date" => "2014-05-01 19:24:12",
         "status" => "pass",
-        "blame" => ["foo 1.1", "bar 2.0"],
         "previous_status" => "pass",
         "duration_seconds" => "45",
         "duration_human" => "0h 0m 45s",
@@ -35,7 +34,6 @@ describe Debci::Status do
     it('gets duration in seconds') { expect(@status.duration_seconds).to eq(45)}
     it('gets duration human') { expect(@status.duration_human).to eq('0h 0m 45s') }
     it('gets message') { expect(@status.message).to eq("All tests passed") }
-    it('gets blame') { expect(@status.blame).to eq(['foo 1.1', 'bar 2.0']) }
   end
 
   context 'with invalid JSON' do
@@ -79,6 +77,26 @@ describe Debci::Status do
       expect(status).to be_newsworthy
     end
 
+    it 'is newsworthy when going from pass to neutral' do
+      status = status_with(status: :neutral, previous_status: :pass)
+      expect(status).to be_newsworthy
+    end
+
+    it 'is newsworthy when going from neutral to pass' do
+      status = status_with(status: :pass, previous_status: :neutral)
+      expect(status).to be_newsworthy
+    end
+
+    it 'is newsworthy when going from neutral to fail' do
+      status = status_with(status: :fail, previous_status: :neutral)
+      expect(status).to be_newsworthy
+    end
+
+    it 'is newsworthy when going from fail to neutral' do
+      status = status_with(status: :neutral, previous_status: :fail)
+      expect(status).to be_newsworthy
+    end
+
     it 'is not newsworthy when keeps passing' do
       status = status_with(status: :pass, previous_status: :pass)
       expect(status).to_not be_newsworthy
@@ -88,6 +106,11 @@ describe Debci::Status do
       status = status_with(status: :fail, previous_status: :fail)
       expect(status).to_not be_newsworthy
     end
+
+      it 'is not newsworthiness when remains neutral' do
+      status = status_with(status: :neutral, previous_status: :neutral)
+      expect(status).to_not be_newsworthy
+    end
   end
 
   context 'headline' do
@@ -104,19 +127,13 @@ describe Debci::Status do
   end
 
   context 'title' do
-    [:pass, :fail, :tmpfail, :no_test_data, :INVALID].each do |s|
+    [:pass, :fail, :neutral, :tmpfail, :no_test_data, :INVALID].each do |s|
       it "should have a title for #{s}" do
         expect(status_with(status: s).title).to be_a(String)
       end
     end
   end
 
-  context 'unknown blame' do
-    it 'is always an Array' do
-      expect(status_with(blame: 'unknown').blame).to be_a(Array)
-    end
-  end
-
   context 'time' do
     time = Debci::Status.new
 
